==> swagger-api__apidom-reference-0.70.0.jar: META-INF/resources/webjars/swagger-api__apidom-reference/0.70.0/es/dereference/strategies/openapi-3-1/selectors/uri/index.js <==
import { isUndefined } from 'ramda-adjunct';
import { find } from '@swagger-api/apidom-core';
import { isSchemaElement } from '@swagger-api/apidom-ns-openapi-3-1';
import { uriToPointer, evaluate as jsonPointerEvaluate } from '@swagger-api/apidom-json-pointer';
import * as url from "../../../../../util/url.js";
import { EvaluationJsonSchemaUriError } from "./errors/index.js";
import { isAnchor, uriToAnchor, evaluate as $anchorEvaluate } from "../$anchor/index.js";
import { resolveSchema$idField } from "../../../../../resolve/strategies/openapi-3-1/util.js"; // evaluates JSON Schema $ref containing unknown URI against ApiDOM fragment
// eslint-disable-next-line import/prefer-default-export
export const evaluate = (uri, element) => {
  const uriStrippedHash = url.stripHash(uri);
  const result = find(
  // @ts-ignore
  e => {
    if (!isSchemaElement(e)) return false;
    if (typeof e.$id === 'undefined') return false;
    const $idBaseURI = resolveSchema$idField(uriStrippedHash, e);
    return $idBaseURI === uriStrippedHash;
  }, element);
  if (isUndefined(result)) {
    throw new EvaluationJsonSchemaUriError(`Evaluation failed on URI: "${uri}"`);
  }
  let fragmentEvaluate;
  let selector;
  if (isAnchor(uriToAnchor(uri))) {
    // we're dealing with JSON Schema $anchor here
    fragmentEvaluate = $anchorEvaluate;
    selector = uriToAnchor(uri);
  } else {
    // we're assuming here that we're dealing with JSON Pointer here
    fragmentEvaluate = jsonPointerEvaluate;
    selector = uriToPointer(uri);
  }

  // @ts-ignore
  return fragmentEvaluate(selector, result);
};
export { EvaluationJsonSchemaUriError };

==> swagger-api__apidom-reference-0.76.0.jar: META-INF/resources/webjars/swagger-api__apidom-reference/0.76.0/es/dereference/strategies/openapi-3-1/selectors/uri/index.js <==
import { isUndefined } from 'ramda-adjunct';
import { filter } from '@swagger-api/apidom-core';
import { isSchemaElement } from '@swagger-api/apidom-ns-openapi-3-1';
import { uriToPointer, evaluate as jsonPointerEvaluate } from '@swagger-api/apidom-json-pointer';
import * as url from "../../../../../util/url.js";
import { EvaluationJsonSchemaUriError } from "./errors/index.js";
import { isAnchor, uriToAnchor, evaluate as $anchorEvaluate } from "../$anchor/index.js";
import { resolveSchema$idField } from "../../../../../resolve/strategies/openapi-3-1/util.js";
/**
 * Evaluates JSON Schema $ref containing unknown URI against ApiDOM fragment.
 */
export const evaluate = (uri, element) => {
  const {
    cache
  } = evaluate;
  const uriStrippedHash = url.stripHash(uri);
  const isSchemaElementWith$id = e => isSchemaElement(e) && typeof e.$id !== 'undefined';

  // warm the cache
  if (!cache.has(element)) {
    const schemaObjectElements = filter(isSchemaElementWith$id, element);
    cache.set(element, Array.from(schemaObjectElements));
  }

  // search for the matching schema
  const result = cache.get(element).find(e => {
    const $idBaseURI = resolveSchema$idField(uriStrippedHash, e);
    return $idBaseURI === uriStrippedHash;
  });
  if (isUndefined(result)) {
    throw new EvaluationJsonSchemaUriError(`Evaluation failed on URI: "${uri}"`);
  }
  let fragmentEvaluate;
  let selector;
  if (isAnchor(uriToAnchor(uri))) {
    // we're dealing with JSON Schema $anchor here
    fragmentEvaluate = $anchorEvaluate;
    selector = uriToAnchor(uri);
  } else {
    // we're assuming here that we're dealing with JSON Pointer here
    fragmentEvaluate = jsonPointerEvaluate;
    selector = uriToPointer(uri);
  }

  // @ts-ignore
  return fragmentEvaluate(selector, result);
};
evaluate.cache = new WeakMap();
export { EvaluationJsonSchemaUriError };
